## Changelog

### `0.1.3` (unreleased)

- [#19] adds a basic Markdown presenter, with slides delimited by `---`
- [#22] adds a stack of previously-viewed documents when navigating between documents
- [#27] adds a drag-and-drop _slide layout_ overlay and design tools to support
  customization
- [#29] adds support for using `#<header>` anchors while presenting

[#19]: https://github.com/deathbeds/jupyterlab-deck/issues/19
[#22]: https://github.com/deathbeds/jupyterlab-deck/issues/22
[#27]: https://github.com/deathbeds/jupyterlab-deck/issues/27
[#29]: https://github.com/deathbeds/jupyterlab-deck/issues/29

### `0.1.2`

- [#17] adds foreground and background layers with customized per-cell styling

[#17]: https://github.com/deathbeds/jupyterlab-deck/issues/15

### `0.1.1`

#### Enhancements

- improve keyboard navigation with (<kbd>shift</kbd>)<kbd>space</kbd>
- the active cell is scrolled into view when exiting presentation mode

#### Bug Fixes

- fix some packaging metadata and documentation issues
- fix handling of `null` cells

### `0.1.0`

_initial release_
